==> v0.26.zip: fargo/fargo/oauth2/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import fargo.oauth2.models


class Migration(migrations.Migration):

    dependencies = [
        ('fargo', '0013_document_mime_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='OAuth2Authorize',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('access_token', models.CharField(default=fargo.oauth2.models.generate_uuid, max_length=255)),
                ('code', models.CharField(default=fargo.oauth2.models.generate_uuid, max_length=255)),
                ('creation_date', models.DateTimeField(auto_now=True)),
                ('user_document', models.ForeignKey(to='fargo.UserDocument')),
            ],
        ),
        migrations.CreateModel(
            name='OAuth2Client',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('client_secret', models.CharField(default=fargo.oauth2.models.generate_uuid, max_length=255)),
                ('client_id', models.CharField(default=fargo.oauth2.models.generate_uuid, max_length=255)),
                ('client_name', models.CharField(max_length=255)),
                ('redirect_uris', models.TextField(verbose_name='redirect URIs', validators=[fargo.oauth2.models.validate_https_url])),
            ],
        ),
        migrations.CreateModel(
            name='OAuth2TempFile',
            fields=[
                ('hash_key', models.CharField(max_length=128, serialize=False, primary_key=True)),
                ('filename', models.CharField(max_length=512)),
                ('document', models.ForeignKey(to='fargo.Document', related_name='oauth2_tempfiles')),
            ],
        ),
    ]

==> v0.40.zip: fargo/fargo/oauth2/migrations/0001_initial.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import fargo.oauth2.models


class Migration(migrations.Migration):

    dependencies = [
        ('fargo', '0013_document_mime_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='OAuth2Authorize',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('access_token', models.CharField(default=fargo.oauth2.models.generate_uuid, max_length=255)),
                ('code', models.CharField(default=fargo.oauth2.models.generate_uuid, max_length=255)),
                ('creation_date', models.DateTimeField(auto_now=True)),
                ('user_document', models.ForeignKey(to='fargo.UserDocument', on_delete=models.CASCADE)),
            ],
        ),
        migrations.CreateModel(
            name='OAuth2Client',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('client_secret', models.CharField(default=fargo.oauth2.models.generate_uuid, max_length=255)),
                ('client_id', models.CharField(default=fargo.oauth2.models.generate_uuid, max_length=255)),
                ('client_name', models.CharField(max_length=255)),
                ('redirect_uris', models.TextField(verbose_name='redirect URIs', validators=[fargo.oauth2.models.validate_https_url])),
            ],
        ),
        migrations.CreateModel(
            name='OAuth2TempFile',
            fields=[
                ('hash_key', models.CharField(max_length=128, serialize=False, primary_key=True)),
                ('filename', models.CharField(max_length=512)),
                ('document', models.ForeignKey(to='fargo.Document', related_name='oauth2_tempfiles', on_delete=models.CASCADE)),
            ],
        ),
    ]
